@@ -1,7 +1,5 @@
 import json
 import os
-import jinja2
-import yaml
 
 from jinja2 import Environment
 from jinja2 import FileSystemLoader
